@@ -2,6 +2,7 @@
 
 import click
 
+from max_div.benchmark import benchmark_diversity_metrics as _benchmark_diversity_metrics
 from max_div.benchmark import benchmark_randint as _benchmark_randint
 from max_div.benchmark import benchmark_randint_constrained as _benchmark_randint_constrained
 
@@ -66,6 +67,15 @@ def randint_constrained(ctx):
     _benchmark_randint_constrained(speed=speed, markdown=markdown)
 
 
+@benchmark.command(name="diversity_metrics")
+@click.pass_context
+def diversity_metrics(ctx):
+    """Benchmarks computation of DiversityMetrics."""
+    speed = ctx.obj["speed"]
+    markdown = ctx.obj["markdown"]
+    _benchmark_diversity_metrics(speed=speed, markdown=markdown)
+
+
 # -------------------------------------------------------------------------
 #  Misc Commands
 # -------------------------------------------------------------------------
